@@ -20,7 +20,7 @@ autoflush STDOUT 1;
 
 # ABSTRACT: C source analysis
 
-our $VERSION = '0.19'; # VERSION
+our $VERSION = '0.21'; # VERSION
 
 # PODNAME: c2ast.pl
 
@@ -351,6 +351,7 @@ where options can be:
                      In practice, only IDENTIFIER, TYPEDEF_NAME and ENUMERATION_CONSTANT are useful.
                      An internal lexeme, not generated by Marpa itself also exist: PREPROCESSOR_LINE_DIRECTIVE.
                      This option must be repeated for every lexeme of interest.
+                     Giving a value __ALL__ will make all lexemes candidates for logging.
                      The output will go to STDOUT.
 
 --progress           Progress bar with ETA information. The "name" associated with the progress bar will the last
@@ -415,7 +416,7 @@ c2ast.pl - C source analysis
 
 =head1 VERSION
 
-version 0.19
+version 0.21
 
 =head1 DESCRIPTION
 
@@ -437,20 +438,6 @@ Say --help on the command-line to have the full list of options, and examples.
 
 Jean-Damien Durand <jeandamiendurand@free.fr>
 
-=head1 CONTRIBUTORS
-
-=over 4
-
-=item *
-
-Jeffrey Kegler <jkegl@cpan.org>
-
-=item *
-
-jddurand <jeandamiendurand@free.fr>
-
-=back
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by Jean-Damien Durand.
